package com.ruoyi.goods.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.goods.domain.TCanteenMenu;
import com.ruoyi.goods.service.ITCanteenMenuService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 菜单Controller
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@RestController
@RequestMapping("/goods/menu")
public class TCanteenMenuController extends BaseController
{
    @Autowired
    private ITCanteenMenuService tCanteenMenuService;

    /**
     * 查询菜单列表
     */
    @PreAuthorize("@ss.hasPermi('goods:menu:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCanteenMenu tCanteenMenu)
    {
        startPage();
        List<TCanteenMenu> list = tCanteenMenuService.selectTCanteenMenuList(tCanteenMenu);
        return getDataTable(list);
    }

    /**
     * 导出菜单列表
     */
    @PreAuthorize("@ss.hasPermi('goods:menu:export')")
    @Log(title = "菜单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCanteenMenu tCanteenMenu)
    {
        List<TCanteenMenu> list = tCanteenMenuService.selectTCanteenMenuList(tCanteenMenu);
        ExcelUtil<TCanteenMenu> util = new ExcelUtil<TCanteenMenu>(TCanteenMenu.class);
        util.exportExcel(response, list, "菜单数据");
    }

    /**
     * 获取菜单详细信息
     */
    @PreAuthorize("@ss.hasPermi('goods:menu:query')")
    @GetMapping(value = "/{menuId}")
    public AjaxResult getInfo(@PathVariable("menuId") Long menuId)
    {
        return success(tCanteenMenuService.selectTCanteenMenuByMenuId(menuId));
    }

    /**
     * 新增菜单
     */
    @PreAuthorize("@ss.hasPermi('goods:menu:add')")
    @Log(title = "菜单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCanteenMenu tCanteenMenu)
    {
        return toAjax(tCanteenMenuService.insertTCanteenMenu(tCanteenMenu));
    }

    /**
     * 修改菜单
     */
    @PreAuthorize("@ss.hasPermi('goods:menu:edit')")
    @Log(title = "菜单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCanteenMenu tCanteenMenu)
    {
        return toAjax(tCanteenMenuService.updateTCanteenMenu(tCanteenMenu));
    }

    /**
     * 删除菜单
     */
    @PreAuthorize("@ss.hasPermi('goods:menu:remove')")
    @Log(title = "菜单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{menuIds}")
    public AjaxResult remove(@PathVariable Long[] menuIds)
    {
        return toAjax(tCanteenMenuService.deleteTCanteenMenuByMenuIds(menuIds));
    }
}
